from ngutils.functions import *

__version__ = '0.9.11'

__all__ = [
    'accel_steps',
    'read_urls_contents',
    'reduce_content',
    'tune_steps',
    'view_types',
]

